==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/DataGridSummaryResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridSummaryResultDescription } from "./DataGridSummaryResultDescription";
/**
 * @hidden
 */
export let DataGridSummaryResultDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataGridSummaryResultDescriptionMetadata extends Base {
        static b(a) {
            if (DataGridSummaryResultDescriptionMetadata.a == null) {
                DataGridSummaryResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataGridSummaryResultDescriptionMetadata.c(DataGridSummaryResultDescriptionMetadata.a);
            }
            if (a.k(DataGridSummaryResultDescriptionMetadata.a)) {
                return;
            }
            a.ab(DataGridSummaryResultDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
            a.item("GroupKeyRef", "(w:GroupKey,wf:GroupKey)DataRef:object");
            a.item("Value", "Unknown");
            a.item("SummaryIndex", "Number:int");
        }
        static d(a) {
            DataGridSummaryResultDescriptionMetadata.b(a);
            a.ad("DataGridSummaryResult", () => new DataGridSummaryResultDescription());
            a.ac("DataGridSummaryResult", DataGridSummaryResultDescriptionMetadata.a);
        }
    }
    DataGridSummaryResultDescriptionMetadata.$t = markType(DataGridSummaryResultDescriptionMetadata, 'DataGridSummaryResultDescriptionMetadata');
    DataGridSummaryResultDescriptionMetadata.a = null;
    return DataGridSummaryResultDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/DataGridSummaryResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridSummaryResultDescription } from "./DataGridSummaryResultDescription";
/**
 * @hidden
 */
export let DataGridSummaryResultDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataGridSummaryResultDescriptionMetadata extends Base {
        static b(a) {
            if (DataGridSummaryResultDescriptionMetadata.a == null) {
                DataGridSummaryResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataGridSummaryResultDescriptionMetadata.c(DataGridSummaryResultDescriptionMetadata.a);
            }
            if (a.k(DataGridSummaryResultDescriptionMetadata.a)) {
                return;
            }
            a.ac(DataGridSummaryResultDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
            a.item("GroupKeyRef", "(w:GroupKey,wf:GroupKey)DataRef:object");
            a.item("Value", "Unknown");
            a.item("SummaryIndex", "Number:int");
            a.item("ShouldDisplay", "Boolean");
        }
        static d(a) {
            DataGridSummaryResultDescriptionMetadata.b(a);
            a.ae("DataGridSummaryResult", () => new DataGridSummaryResultDescription());
            a.ad("DataGridSummaryResult", DataGridSummaryResultDescriptionMetadata.a);
        }
    }
    DataGridSummaryResultDescriptionMetadata.$t = markType(DataGridSummaryResultDescriptionMetadata, 'DataGridSummaryResultDescriptionMetadata');
    DataGridSummaryResultDescriptionMetadata.a = null;
    return DataGridSummaryResultDescriptionMetadata;
})();
